@@ -1,5 +1,4 @@
 import subprocess, argparse, wget, requests, json, urllib.request, pip
-from pip._internal.operations.freeze import freeze
 from LibreGaming.distro_pkgs.Arch import Arch 
 from LibreGaming.distro_pkgs.Fedora import Fedora
 from LibreGaming.distro_pkgs.OpenSUSE import OpenSUSE 
@@ -52,6 +51,7 @@ class LibreGaming:
         elif whoami != "root" and authorize == True:
            print("\nPlease run LibreGaming with sudo or doas command for this flag")
            exit(0)
+        return authorize
 
     # Used to install all packages 
     def installAllPkgs(self):
